.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide_addons.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
cpskin.citizen
==============================================================================


Contribute
----------

- Issue Tracker: https://github.com/collective/cpskin.citizen/issues
- Source Code: https://github.com/collective/cpskin.citizen


Support
-------

If you are having issues, please let us know.


License
-------

The project is licensed under the GPLv2.


Tests
-----

This package is tested using Travis CI. The current status of the add-on is :

.. image:: https://api.travis-ci.org/IMIO/cpskin.citizen.png
    :target: http://travis-ci.org/IMIO/cpskin.citizen
